# Variants

Dialect-specific builders built on top of the core `CreateBuilder`.

## Available Variants

- **Spark/Delta Lake** - Delta Lake tables with CDF support
- **Hive** - Apache Hive tables with SERDE/ROW FORMAT
- **PostgreSQL** - PostgreSQL-specific features
- **DuckDB** - DuckDB-specific features
- **BigQuery** - BigQuery-specific features
